==> ugene_40.1+dfsg.orig.tar.xz: ugene-40.1/src/corelibs/U2Algorithm/src/util_msaedit/color_schemes/MsaColorSchemePercentageIdentity.h <==
/**
 * UGENE - Integrated Bioinformatics Tools.
 * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
 * http://ugene.net
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA 02110-1301, USA.
 */

#ifndef _U2_MSA_COLOR_SCHEME_PERCENTAGE_IDENTITY_H_
#define _U2_MSA_COLOR_SCHEME_PERCENTAGE_IDENTITY_H_

#include <QColor>
#include <QVector>

#include "MsaColorScheme.h"

namespace U2 {

class U2ALGORITHM_EXPORT MsaColorSchemePercentageIdentity : public MsaColorScheme {
    Q_OBJECT
public:
    MsaColorSchemePercentageIdentity(QObject *parent, const MsaColorSchemeFactory *factory, MultipleAlignmentObject *maObj);

    QColor getBackgroundColor(int seq, int pos, char c) const override;
    QColor getFontColor(int seq, int pos, char c) const override;

private slots:
    void sl_alignmentChanged();

protected:
    void updateCache() const;

    mutable QVector<quint32> indentCache;
    mutable int cacheVersion;
    int objVersion;
    QColor colorsByRange[4];
    int mask4[4];
    mutable char tmpChars[4];
    mutable int tmpRanges[4];
};

class MsaColorSchemePercentageIdentityFactory : public MsaColorSchemeFactory {
    Q_OBJECT
public:
    MsaColorSchemePercentageIdentityFactory(QObject *parent, const QString &id, const QString &name, const AlphabetFlags &supportedAlphabets);

    MsaColorScheme *create(QObject *parent, MultipleAlignmentObject *maObj) const;
};

}  // namespace U2

#endif  // _U2_MSA_COLOR_SCHEME_PERCENTAGE_IDENTITY_H_

==> ugene_49.1+dfsg.orig.tar.xz: ugene-49.1/src/corelibs/U2Algorithm/src/util_msaedit/color_schemes/MsaColorSchemePercentageIdentity.h <==
/**
 * UGENE - Integrated Bioinformatics Tools.
 * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
 * http://ugene.net
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA 02110-1301, USA.
 */

#pragma once

#include <QColor>
#include <QVector>

#include "MsaColorScheme.h"

namespace U2 {

class U2ALGORITHM_EXPORT MsaColorSchemePercentageIdentity : public MsaColorScheme {
    Q_OBJECT
public:
    MsaColorSchemePercentageIdentity(QObject* parent, const MsaColorSchemeFactory* factory, MultipleAlignmentObject* maObj);

    QColor getBackgroundColor(int seq, int pos, char c) const override;
    QColor getFontColor(int seq, int pos, char c) const override;

private slots:
    void sl_alignmentChanged();

protected:
    void updateCache() const;

    mutable QVector<quint32> indentCache;
    mutable int cacheVersion;
    int objVersion;
    QColor colorsByRange[4];
    int mask4[4];
    mutable char tmpChars[4];
    mutable int tmpRanges[4];
};

class MsaColorSchemePercentageIdentityFactory : public MsaColorSchemeFactory {
    Q_OBJECT
public:
    MsaColorSchemePercentageIdentityFactory(QObject* parent, const QString& id, const QString& name, const AlphabetFlags& supportedAlphabets);

    MsaColorScheme* create(QObject* parent, MultipleAlignmentObject* maObj) const;
};

}  // namespace U2
